==> pan-0.7.0.tar.gz: pan-0.7.0/pan/articlelist.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __ARTICLE_LIST_H__
#define __ARTICLE_LIST_H__

#include <gdk/gdk.h>
#include <gtk/gtkstyle.h>

#include "article-db.h"
#include "server.h"
#include "group.h"
#include "status-item.h"

extern GdkColormap *cmap;
extern GdkColor read_color;
extern GdkColor unread_color;
extern GdkColor new_color;
extern GdkColor killfile_color;

extern GtkStyle *unread_style;
extern GtkStyle *read_style;
extern GtkStyle *new_style;
extern GtkStyle *killfile_style;

/* state info */
extern const group_data* articlelist_get_current_group(void);
extern const server_data* articlelist_get_current_server(void);
extern void articlelist_set_current_group (server_data *, group_data *);

/* stepping through the articles */
extern const char* articlelist_get_selected_message_id (void);
extern void articlelist_set_selected_message_id (const char* message_id);
extern const char* articlelist_get_next_message_id (const char* message_id, int step);
extern article_data* articlelist_get_previous_article (void);
extern article_data* articlelist_get_next_article (void);

/* more stepping */
extern void articlelist_read_next_article(void);
extern void articlelist_read_next_unread_article(void);
extern void articlelist_read_next_thread(void);
extern void articlelist_read_prev_article(void);
extern void articlelist_read_prev_unread_article(void);
extern void articlelist_read_prev_thread(void);

/* contents */
extern void articlelist_load (const server_data*, group_data*, StatusItem*);
/* this emits the "next step" signal between alist_total*2 and alist_total*3 times, depending on the killfile */
extern void articlelist_set_contents (const server_data*, const group_data*, GSList* adata_list, int adata_qty, StatusItem*);
extern void articlelist_clear (void);
extern void articlelist_queue_reload (void);
extern void articlelist_update_node (const article_data* adata);

/* "find" dialog interaction with articlelist */
extern void articlelist_find_text_cb (void);
extern void articlelist_find_next_cb (void);
extern void find_dialog_destroy_cb (void);

/* article operations */
extern void articlelist_select_all (void);
extern void articlelist_selected_decode (void);
extern void articlelist_selected_delete (void);
extern void articlelist_selected_mark_read (void);
extern void articlelist_selected_mark_unread (void);
extern void articlelist_selected_open (void);
extern void articlelist_all_mark_read (void);
extern void articlelist_expire (article_db, group_data *);

/* util */
extern GtkWidget* create_articlelist_ctree (void);


#endif /* __ARTICLE_LIST_H__ */

==> pan-0.7.3.tar.gz: pan-0.7.3/pan/articlelist.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __ARTICLE_LIST_H__
#define __ARTICLE_LIST_H__

#include <gdk/gdk.h>
#include <gtk/gtkstyle.h>

#include "article-db.h"
#include "server.h"
#include "group.h"
#include "status-item.h"

extern GdkColormap *cmap;
extern GdkColor read_color;
extern GdkColor unread_color;
extern GdkColor new_color;
extern GdkColor killfile_color;

extern GtkStyle *unread_style;
extern GtkStyle *read_style;
extern GtkStyle *new_style;
extern GtkStyle *killfile_style;

extern gboolean hide_mpart_child_nodes;

/* state info */
extern group_data* articlelist_get_current_group(void);
extern const server_data* articlelist_get_current_server(void);
extern void articlelist_set_current_group (server_data *, group_data *);

/* stepping through the articles */
extern const char* articlelist_get_selected_message_id (void);
extern void articlelist_set_selected_message_id (const char* message_id);
extern const article_data* articlelist_get_previous_article (void);
extern const article_data* articlelist_get_next_article (void);

/* more stepping */
extern void articlelist_read_next_article(void);
extern void articlelist_read_next_unread_article(void);
extern void articlelist_read_next_thread(void);
extern void articlelist_read_prev_article(void);
extern void articlelist_read_prev_unread_article(void);
extern void articlelist_read_prev_thread(void);

/* contents */
extern void articlelist_load (server_data*, group_data*, StatusItem*);
/* this emits the "next step" signal between alist_total*2 and alist_total*3 times, depending on the killfile */
extern void articlelist_set_contents (server_data*, group_data*, GSList* adata_list, int adata_qty, StatusItem*);
extern void articlelist_clear (void);
extern void articlelist_queue_reload (void);
extern void articlelist_update_node (const article_data* adata);

/* "find" dialog interaction with articlelist */
extern void articlelist_find_text_cb (void);
extern void articlelist_find_next_cb (void);
extern void find_dialog_destroy_cb (void);

/* article operations */
extern void articlelist_select_all (void);
extern void articlelist_selected_decode (void);
extern void articlelist_selected_delete (void);
extern void articlelist_selected_mark_read (void);
extern void articlelist_selected_mark_unread (void);
extern void articlelist_selected_open (void);
extern void articlelist_all_mark_read (void);
extern void articlelist_expire (article_db, group_data *);

/* util */
extern GtkWidget* create_articlelist_ctree (void);


/* toolbar */
extern GtkWidget* articlelist_create_toolbar (void);

#endif /* __ARTICLE_LIST_H__ */
